@@ -127,10 +127,16 @@ read_data <-
     }
 
     #remove leading and trailing zeros
-    if(length(dat)>0 && !all(is.na(dat)))
+    if(length(dat)>0 && !all(is.na(dat))){
       dat[,3] <- suppressWarnings(
         as.character(as.numeric(dat[,3]))
       )
+      # revise values in the second column. Values like "1A" should become 1, "2B" should become 2, etc. Coerce to integer
+      dat[,2] <- gsub("[A-Z]", "", dat[,2], ignore.case = TRUE)
+      dat[,2] <- suppressWarnings(as.integer(dat[,2], na.rm = TRUE))
+    }
+
+
 
     if(data.format == "col"){
       message("Sample data are stored in columns. If they are stored in row format, please run read_data() with data.format = 'row'.")
@@ -504,7 +510,66 @@ read_data <-
       colnames(fl.norm.mat) <- rep("", ncol(fl.norm.mat))
       colnames(fl.norm.mat)[1:3] <- c("condition", "replicate", "concentration")
     }
+    # -------------------------------------------------
+    # fix up the `condition` column so that
+    #  - "1.000" → "1"
+    #  - "2.500" → "2.500"  (left as-is, since not integer)
+    #  - then any pure integer → "Condition<integer>"
+    # -------------------------------------------------
+    prefix_numeric_conditions <- function(df_mat) {
+      # 1) coerce to character
+      cond <- as.character(df_mat[ , "condition"])
+      # 2) strip off any trailing decimal zeros
+      cond_clean <- trimws(sub("\\.0+$", "", cond))
+      # 3) detect which are now only digits
+      is_int <- grepl("^[0-9]+$", cond_clean)
+      # 4) prefix those with "Condition"
+      cond_clean[is_int] <- paste0("Condition", cond_clean[is_int])
+      # 5) write it back
+      df_mat[ , "condition"] <- cond_clean
+      df_mat
+    }
+    # apply to your three matrices, if they exist:
+    if (length(dat.mat) > 1)            dat.mat   <- prefix_numeric_conditions(dat.mat)
+    if ((length(fl) > 1) || !is.na(data.fl))         fl.mat    <- prefix_numeric_conditions(fl.mat)
+    if (((length(fl) > 1) || !is.na(data.fl)) && length(dat) > 1)
+      fl.norm.mat <- prefix_numeric_conditions(fl.norm.mat)
 
+    # # Ensure any numeric-only condition IDs get a "Condition" prefix
+    # # (we do it after create_datmat so that it applies equally to growth, fl, and fl.norm)
+    # prefix_numeric_conditions <- function(df_mat) {
+    #   # detect rows where 'condition' is digits only
+    #   is_num_only <- grepl("^[0-9]+(\\.[0-9]+)?$", df_mat[, "condition"])
+    #   if (any(is_num_only)) {
+    #     df_mat[is_num_only, "condition"] <- paste0("Condition", df_mat[is_num_only, "condition"])
+    #   }
+    #   return(df_mat)
+    # }
+    #
+    # if (length(dat.mat) > 1) {
+    #   dat.mat <- prefix_numeric_conditions(dat.mat)
+    # }
+    # if ((length(fl) > 1) || !is.na(data.fl)) {
+    #   fl.mat <- prefix_numeric_conditions(fl.mat)
+    # }
+    # if (((length(fl) > 1) || !is.na(data.fl)) && length(dat) > 1) {
+    #   fl.norm.mat <- prefix_numeric_conditions(fl.norm.mat)
+    # }
+    if(length(dat) > 1) {
+      dat.mat[, 1] <- trimws(dat.mat[, 1])
+      dat.mat[, 2] <- trimws(dat.mat[, 2])
+      dat.mat[, 3] <- trimws(dat.mat[, 3])
+    }
+    if(length(fl) > 1){
+      fl.mat[, 1] <- trimws(fl.mat[, 1])
+      fl.mat[, 2] <- trimws(fl.mat[, 2])
+      fl.mat[, 3] <- trimws(fl.mat[, 3])
+    }
+    if(length(fl.norm.mat) > 1){
+      fl.norm.mat[, 1] <- trimws(fl.norm.mat[, 1])
+      fl.norm.mat[, 2] <- trimws(fl.norm.mat[, 2])
+      fl.norm.mat[, 3] <- trimws(fl.norm.mat[, 3])
+    }
     if(length(dat) > 1) {
       label <- unlist(lapply(1:nrow(dat.mat), function(x) paste(dat.mat[x,1], dat.mat[x,2], dat.mat[x,3], sep = " | ")))
       condition <- dat.mat[, 1]
@@ -523,7 +588,6 @@ read_data <-
     #   concentration <- fl2.mat[, 3]
     # }
 
-
     expdesign <- data.frame(label, condition, replicate, concentration, check.names = FALSE)
 
     if(length(dat)>1){
